@@ -13,16 +13,16 @@ from ossapi.models import (Beatmap, BeatmapCompact, BeatmapUserScore,
     Spotlights, WikiPage, _Event, Event, BeatmapsetDiscussionPosts, Build,
     ChangelogListing, MultiplayerScores, MultiplayerScoresCursor,
     BeatmapsetDiscussionVotes, CreatePMResponse, BeatmapsetDiscussions,
-    UserCompact)
+    UserCompact, BeatmapsetCompact)
 from ossapi.enums import (GameMode, ScoreType, RankingFilter, RankingType,
     UserBeatmapType, BeatmapDiscussionPostSort, UserLookupKey,
     BeatmapsetEventType, CommentableType, CommentSort, ForumTopicSort,
     SearchMode, MultiplayerScoresSort, BeatmapsetDiscussionVote,
     BeatmapsetDiscussionVoteSort, BeatmapsetStatus, MessageType)
-from ossapi.utils import Expandable
 from ossapi.mod import Mod
 from ossapi.replay import Replay
 from ossapi.version import __version__
+from ossapi.encoder import ModelEncoder, serialize_model
 
 from oauthlib.oauth2 import AccessDeniedError, TokenExpiredError
 from oauthlib.oauth2.rfc6749.errors import InsufficientScopeError
@@ -42,7 +42,7 @@ __all__ = [
     "Spotlights", "WikiPage", "_Event", "Event", "BeatmapsetDiscussionPosts",
     "Build", "ChangelogListing", "MultiplayerScores", "MultiplayerScoresCursor",
     "BeatmapsetDiscussionVotes", "CreatePMResponse",
-    "BeatmapsetDiscussions", "UserCompact",
+    "BeatmapsetDiscussions", "UserCompact", "BeatmapsetCompact",
     # OssapiV2 enums
     "GameMode", "ScoreType", "RankingFilter", "RankingType",
     "UserBeatmapType", "BeatmapDiscussionPostSort", "UserLookupKey",
@@ -52,5 +52,6 @@ __all__ = [
     # OssapiV2 exceptions
     "AccessDeniedError", "TokenExpiredError", "InsufficientScopeError",
     # misc
-    "Mod", "Replay", "__version__"
+    "Mod", "Replay", "__version__", "ModelEncoder",
+    "serialize_model"
 ]
