@@ -111,6 +111,8 @@ class UserCompact(Model):
     friends: Optional[List[UserRelation]]
     graveyard_beatmapset_count: Optional[int]
     groups: Optional[List[UserGroup]]
+    # undocumented
+    guest_beatmapset_count: Optional[int]
     is_admin: Optional[bool]
     is_bng: Optional[bool]
     is_full_bn: Optional[bool]
@@ -261,6 +263,7 @@ class BeatmapsetCompact(Model):
     video: bool
     nsfw: bool
     offset: int
+    spotlight: bool
     # documented as being in ``Beatmapset`` only, but returned by
     # ``api.beatmapset_events`` which uses a ``BeatmapsetCompact``.
     hype: Optional[Hype]
@@ -350,6 +353,9 @@ class BeatmapUserScore(Model):
     position: int
     score: Score
 
+class BeatmapUserScores(Model):
+    scores: List[Score]
+
 class BeatmapScores(Model):
     scores: List[Score]
     userScore: Optional[BeatmapUserScore]
@@ -366,6 +372,7 @@ class CommentableMeta(Model):
     # both undocumented
     owner_id: Optional[int]
     owner_title: Optional[str]
+    current_user_attributes: Any
 
 class Comment(Model):
     commentable_id: int
@@ -782,6 +789,35 @@ class SeasonalBackground(Model):
     url: str
     user: UserCompact
 
+class DifficultyAttributes(Model):
+    attributes: BeatmapDifficultyAttributes
+
+class BeatmapDifficultyAttributes(Model):
+    max_combo: int
+    star_rating: float
+
+    # osu attributes
+    aim_difficulty: Optional[float]
+    approach_rate: Optional[float]
+    flashlight_difficulty: Optional[float]
+    overall_difficulty: Optional[float]
+    slider_factor: Optional[float]
+    speed_difficulty: Optional[float]
+
+    # taiko attributes
+    stamina_difficulty: Optional[float]
+    rhythm_difficulty: Optional[float]
+    colour_difficulty: Optional[float]
+    approach_raty: Optional[float]
+    great_hit_windoy: Optional[float]
+
+    # ctb attributes
+    approach_rate: Optional[float]
+
+    # mania attributes
+    great_hit_window: Optional[float]
+    score_multiplier: Optional[float]
+
 
 # ===================
 # Undocumented Models
