@@ -26,7 +26,8 @@ from ossapi.models import (Beatmap, BeatmapCompact, BeatmapUserScore,
     Spotlights, WikiPage, _Event, Event, BeatmapsetDiscussionPosts, Build,
     ChangelogListing, MultiplayerScores, MultiplayerScoresCursor,
     BeatmapsetDiscussionVotes, CreatePMResponse, BeatmapsetDiscussions,
-    UserCompact, NewsListing, NewsPost, SeasonalBackgrounds, BeatmapsetCompact)
+    UserCompact, NewsListing, NewsPost, SeasonalBackgrounds, BeatmapsetCompact,
+    BeatmapUserScores, DifficultyAttributes)
 from ossapi.enums import (GameMode, ScoreType, RankingFilter, RankingType,
     UserBeatmapType, BeatmapDiscussionPostSort, UserLookupKey,
     BeatmapsetEventType, CommentableType, CommentSort, ForumTopicSort,
@@ -432,6 +433,8 @@ class OssapiV2:
 
     def _request(self, type_, method, url, params={}, data={}):
         params = self._format_params(params)
+        # also format data for post requests
+        data = self._format_params(data)
         try:
             r = self.session.request(method, f"{self.BASE_URL}{url}",
                 params=params, data=data)
@@ -765,6 +768,20 @@ class OssapiV2:
         return self._get(BeatmapUserScore,
             f"/beatmaps/{beatmap_id}/scores/users/{user_id}", params)
 
+    @request(Scope.PUBLIC)
+    def beatmap_user_scores(self,
+        beatmap_id: BeatmapIdT,
+        user_id: UserIdT,
+        mode: Optional[GameModeT] = None
+    ) -> List[BeatmapUserScore]:
+        """
+        https://osu.ppy.sh/docs/index.html#get-a-user-beatmap-scores
+        """
+        params = {"mode": mode}
+        scores = self._get(BeatmapUserScores,
+            f"/beatmaps/{beatmap_id}/scores/users/{user_id}/all", params)
+        return scores.scores
+
     @request(Scope.PUBLIC)
     def beatmap_scores(self,
         beatmap_id: BeatmapIdT,
@@ -862,6 +879,21 @@ class OssapiV2:
         return self._get(BeatmapsetDiscussions,
             "/beatmapsets/discussions", params)
 
+    @request(Scope.PUBLIC)
+    def beatmap_attributes(self,
+        beatmap_id: int,
+        mods: Optional[ModT] = None,
+        ruleset: Optional[GameModeT] = None,
+        ruleset_id: Optional[int] = None
+    ) -> DifficultyAttributes:
+        """
+        https://osu.ppy.sh/docs/index.html#get-beatmap-attributes
+        """
+        data = {"mods": mods, "ruleset": ruleset, "ruleset_id": ruleset_id}
+        return self._post(DifficultyAttributes,
+            f"/beatmaps/{beatmap_id}/attributes", data=data)
+
+
     # /changelog
     # ----------
 
@@ -1111,6 +1143,14 @@ class OssapiV2:
         """
         https://osu.ppy.sh/docs/index.html#get-user-scores
         """
+        # `include_fails` is actually a string in the api spec. We'll still
+        # require a bool to be passed, and just do the conversion behind the
+        # scenes.
+        if include_fails is False:
+            include_fails = 0
+        if include_fails is True:
+            include_fails = 1
+
         params = {"include_fails": include_fails, "mode": mode, "limit": limit,
             "offset": offset}
         return self._get(List[Score], f"/users/{user_id}/scores/{type_.value}",
