@@ -1,7 +1,7 @@
 from unittest import TestCase
 
 from ossapi import (RankingType, BeatmapsetEventType, AccessDeniedError,
-    InsufficientScopeError)
+    InsufficientScopeError, Mod)
 
 from tests import api
 
@@ -61,6 +61,10 @@ class TestBeatmapUserScore(TestCase):
     def test_deserialize(self):
         api.beatmap_user_score(beatmap_id=221777, user_id=2757689, mode="osu")
 
+class TestBeatmapUserScores(TestCase):
+    def test_deserialize(self):
+        api.beatmap_user_scores(beatmap_id=221777, user_id=2757689, mode="osu")
+
 class TestSearch(TestCase):
     def test_deserialize(self):
         api.search(query="peppy")
@@ -137,6 +141,12 @@ class TestSeasonalBackgrounds(TestCase):
     def test_deserialize(self):
         api.seasonal_backgrounds()
 
+class TestBeatmapAttributes(TestCase):
+    def test_deserialize(self):
+        api.beatmap_attributes(221777, ruleset="osu")
+        api.beatmap_attributes(221777, mods=Mod.HDDT)
+        api.beatmap_attributes(221777, mods="HR")
+        api.beatmap_attributes(221777, ruleset_id=0)
 
 # TODO requires friends.read scope
 # class TestFriends(TestCase):
